@@ -21,7 +21,7 @@ if(inherits(x,"MFA")){
   partial3=FALSE
   selectvar2=NULL
   selectionMFAshiny <- gettext("No selection",domain="R-Factoshiny")
-  selection2MFAshiny <- NULL
+  selection2MFAshiny <- 0
   hide=gettext("Nothing",domain="R-Factoshiny")
   colorvar=TRUE
   freq1=TRUE
